@@ -99,7 +99,7 @@ def count_import_all_registered_customer_function():
 def import_all_registered_customer_function(credential_info=None, dataset_name='system_dataset', 
                                             limit=analytics_conf.STREAM_DATA_PAGE_SIZE, start_cursor=None, batch_id=None):     
     
-    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH)
+    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH, project_id=analytics_conf.BIGQUERY_GCLOUD_PROJECT_ID)
     
     if credential_info is None:
         credential_info = current_app.config['credential_config']
@@ -245,7 +245,7 @@ def import_merchant_registered_customer_function(credential_info=None, dataset_n
                                             partition_date = True, 
                                             limit=analytics_conf.STREAM_DATA_PAGE_SIZE, start_cursor=None, batch_id=None):     
     
-    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH)
+    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH, project_id=analytics_conf.BIGQUERY_GCLOUD_PROJECT_ID)
     
     if credential_info is None:
         credential_info = current_app.config['credential_config']
@@ -325,7 +325,7 @@ def trigger_customer_changes(customer_key):
     return 'Completed', 200
     
 def import_merchant_customer_changes(customer_key, credential_info=None):
-    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH)
+    bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH, project_id=analytics_conf.BIGQUERY_GCLOUD_PROJECT_ID)
     
     if credential_info is None:
         credential_info = current_app.config['credential_config']
